@@ -38,7 +38,7 @@ single 'B<#>' character as entries that have been commented out by a
 user. It will not change such entries.
 
 For shell scripts you can also use the B<update-inetd> command. See
-B<update-inetd>(8) for further information.
+L<update-inetd(8)> for further information.
 
 =cut
 
@@ -56,33 +56,35 @@ use List::Util qw(any none);
 use Debconf::Client::ConfModule ();
 
 BEGIN {
-    eval 'use File::Temp qw/ tempfile /';
+    eval 'use File::Temp qw(tempfile)';
     if ($@) {
         # If perl-base and perl-modules are out of sync, fall back to the
-        # external 'tempfile' command.  In this case we don't bother trying
-        # to mangle the template we're given into something that tempfile
+        # external 'mktemp' command. In this case we do not bother trying
+        # to mangle the template we are given into something that 'mktemp'
         # can understand.
         *tempfile = sub {
-            open my $tempfile_fh, '-|', 'tempfile'
-                or _error("cannot run 'tempfile': $!");
-            chomp (my $tempfile_name = <$tempfile_fh>);
-            unless (length $tempfile_name) {
-                _error("'tempfile' process did not return a temporary file name");
+            my $template = shift;
+
+            open my $mktemp_fh, '-|', 'mktemp', $template
+                or _error("cannot run 'mktemp': $!");
+            chomp (my $mktemp_name = <$mktemp_fh>);
+            unless (length $mktemp_name) {
+                _error("'mktemp' process did not return a temporary file name");
             }
-            unless (close $tempfile_fh) {
+            unless (close $mktemp_fh) {
                 if ($!) {
-                    _error("cannot close 'tempfile' pipe: $!");
+                    _error("cannot close 'mktemp' pipe: $!");
                 } else {
-                    _error("'tempfile' process returned exit status $?");
+                    _error("'mktemp' process returned exit status $?");
                 }
             }
-            open my $fh, '+<', $tempfile_name
-                or _error("cannot open temporary file $tempfile_name: $!");
-            return ($fh, $tempfile_name);
+            open my $fh, '+<', $mktemp_name
+                or _error("cannot open temporary file $mktemp_name: $!");
+            return ($fh, $mktemp_name);
         };
     }
 
-    eval 'use File::Copy qw/ move /';
+    eval 'use File::Copy qw(move)';
     if ($@) {
         # If perl-base and perl-modules are out of sync, fall back to the
         # external 'mv' command.
@@ -566,7 +568,7 @@ sub _wakeup_inetd {
     }
 
     my $fake_invocation = defined $ENV{UPDATE_INETD_FAKE_IT};
-    if (open my $pid_fh, '<', '/var/run/inetd.pid') {
+    if (open my $pid_fh, '<', '/run/inetd.pid') {
         $pid = <$pid_fh>;
         chomp $pid;
         my $pid_stat = sprintf '/proc/%d/stat', $pid;
@@ -578,7 +580,7 @@ sub _wakeup_inetd {
                     kill 1, $pid;
                 }
             } else {
-                warn "/var/run/inetd.pid does not have a valid pid!\n";
+                warn "/run/inetd.pid does not have a valid pid!\n";
                 warn "Please investigate and restart inetd manually.\n";
             }
             close $cmd_fh;
